export interface DeferredLink extends Partial<HTMLLinkElement> {
    href: string;
    onDefer?: (link: DeferredLink) => void;
}
export declare const deferCssData: Record<string, {
    total: number;
    loaded: number;
}>;
/**
 * Defer Css Function
 * @param links - Array of links to defer
 * @param mountId - Id of the element to mount the links on
 *
 * @example
 * ```javascript
 * deferCss(['main-css-1.css', 'main-css-2.css'], 'main-css');
 * deferCss([
 *     { href: 'other-css-1.css', crossorigin: 'anonymous'},
 *     'other-css-2.css'
 * ], 'other-css');
 * ```
 *
 * This will result to.
 * ```html
 * <link rel="stylesheet" href="main-css-1.css">
 * <link rel="stylesheet" href="main-css-2.css">
 * <style>
 *     .some-style-before-other-css{
 *         background: teal;
 *     }
 * </style>
 * <link rel="stylesheet" href="other-css-1.css" crossorigin="anonymous">
 * <link rel="stylesheet" href="other-css-2.css">
 * ```
 */
export declare function deferCss(links: string | DeferredLink | (string | DeferredLink)[], mountId?: string): void;
/**
 * hasStyleSheet - Check if a stylesheet is loaded
 * @param search
 */
export declare function hasStyleSheet(search: string): boolean;
/**
 * getStyleSheetProperty - Get a stylesheet property, if not found returns undefined
 * @param search
 * @param $return
 */
export declare function getStyleSheetProperty<K extends keyof CSSStyleSheet>(search: string, $return: K): CSSStyleSheet[K] | undefined;
/**
 * getStyleSheet - Get a stylesheet, if not found returns undefined
 * @param search
 */
export declare function getStyleSheet(search: string): CSSStyleSheet | undefined;
